@@ -248,6 +248,7 @@ class Madx(object):
         :returns: whether the command has completed without error
         :rtype: bool
         """
+        text = text.rstrip(';') + ';'
         if self._enter_count > 0:
             self._batch.append(text)
             return True
@@ -492,10 +493,10 @@ class _Mapping(abc.Mapping):
             return self[key]
         except KeyError:
             pass
-        return self._missing(key)
+        raise AttributeError(self._missing(key))
 
     def _missing(self, key):
-        raise AttributeError(key)
+        return key
 
 
 class _MutableMapping(_Mapping, abc.MutableMapping):
@@ -789,8 +790,8 @@ class Command(_MutableMapping):
         return self._madx.elements.get(name)
 
     def _missing(self, key):
-        raise AttributeError('Unknown attribute {!r} for {!r} command!'
-                             .format(key, self.name))
+        return ('Unknown attribute {!r} for {!r} command!'
+                .format(key, self.name))
 
     @property
     def defs(self):
